# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Released]

## [0.0.5] - 2024-03-04

### Added

- Bump version

### Changed

- N/A

### Fixed

- N/A

## [0.0.4] - 2024-03-04

### Added

- Added changed log.
- Added workflow for PyPI publishing

### Changed

- N/A

### Fixed

- N/A